Crate tktax_3p Copy item path Source pub use csv ;pub use tracing_subscriber ;pub use chrono ;pub use rust_decimal ;pub use derive_builder ;callsite Callsites represent the source locations from which spans or events
originate. colored Coloring terminal so simple, you already know how to do it ! convert Traits for conversions between types. de Generic data structure deserialization framework. dispatcher Dispatches trace events to Subscriber s. env Inspection and manipulation of the process’s environment. event Events represent single points in time during the execution of a program. field Span and Event key-value data.fmt Utilities for formatting and printing strings. instrument Attach a span to a std::future::Future. level_filters Trace verbosity level filtering. metadata Metadata describing trace data. paste github crates-io docs-rs span Spans represent periods of time in which a program was executing in a
particular context. subscriber Collects and records trace data. bitflags The macro used to generate the flag structures. concatenate Concatenate arrays along the given axis. debug Constructs an event at the debug level. debug_span Constructs a span at the debug level. delegate enabled Checks whether a span or event is enabled based on the provided metadata . enhanced_enum Define a new Enhanced Enum. env Inspects an environment variable at compile time. error Constructs an event at the error level. error_span Constructs a span at the error level. error_tree event Constructs a new Event. event_enabled Tests whether an event with the specified level and target would be enabled. indoc Unindent and produce &'static str or &'static [u8]. info Constructs an event at the info level. info_span Constructs a span at the info level. ix lazy_static metadata Statically constructs new span metadata . setup_test_logger span Constructs a new span. span_enabled Tests whether a span with the specified level and target would be enabled. trace Constructs an event at the trace level. trace_span Constructs a span at the trace level. warn Constructs an event at the warn level. warn_span Constructs a span at the warn level. x xp assert_matches Experimental Asserts that an expression matches the provided pattern. Arc A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically
Reference Counted’. ArrayBase An n -dimensional array. Axis An axis index. BufferedLayer BufferedSubscriberLayer ConfigConfig A prioritized configuration repository. ConfigEnvironment An environment source collects a dictionary of environment variables values into a hierarchical
config Value type. We have to be aware how the config tree is created from the environment
dictionary, therefore we are mindful about prefixes for the environment keys, level separators,
encoding form (kebab, snake case) etc. ConfigFile A configuration source backed up by a file. ConfusionMatrix Confusion matrix for multi-label evaluation CountVectorizer Counts the occurrences of each vocabulary entry, learned during fitting, in a sequence of documents. Each vocabulary entry is mapped
to an integer value that is used to index the count in the result. CountVectorizerParams Cursor A Cursor wraps an in-memory buffer and provides it with a
Seek implementation. DatasetBase DatasetBase DateTime ISO 8601 combined date and time with time zone. Decimal Decimal represents a 128 bit representation of a fixed-precision decimal number.
The finite set of values of type Decimal are of the form m / 10e ,
where m is an integer such that -296 < m < 296 , and e is an integer
between 0 and 28 inclusive.Dispatch Dispatch trace data to a Subscriber .EnvFilter A Layer which filters spans and events based on a set of filter
directives. Event Events represent single points in time where something occurred during the
execution of a program.File An object providing access to an open file on the filesystem. FileLoggingConfiguration GaussianNb Fitted Gaussian Naive Bayes classifier. HashMap A hash map implemented with quadratic probing and SIMD lookup. HashSet A hash set implemented as a HashMap where the value is (). Id Identifies a span within the context of a subscriber. Level Describes the level of verbosity of a span or event. Metadata Metadata describing a span or event . NaiveDate ISO 8601 calendar date without timezone.
Allows for every proleptic Gregorian date from Jan 1, 262145 BCE to Dec 31, 262143 CE.
Also supports the conversion from ISO 8601 ordinal and week date. NaiveDateTime ISO 8601 combined date and time without timezone. OwnedRepr Array’s representation. Path A slice of a path (akin to str ). PathBuf An owned, mutable path (akin to String ). PearsonCorrelation Pearson Correlation Coefficients (or Bivariate Coefficients) Pr Probability types Range A (half-open) range bounded inclusively below and exclusively above
(start..end). ReaderBuilder Builds a CSV reader with various configuration knobs. Regex A compiled regular expression for searching Unicode haystacks. Span A handle representing a span, with the capability to enter the span if it
exists. Stemmer Wrapps a usable interface around the actual stemmer implementation StrftimeItems Parsing iterator for strftime-like format strings. UninitializedFieldError Runtime error when a build() method is called and one or more required fields
do not have a value. Utc The UTC time zone. This is the most efficient time zone when you don’t need the local time.
It is also used as an offset (which is also a dummy type). Algorithm Enum of all supported algorithms.
Check the Snowball-Website for details. ConfigError Represents all possible errors that can occur when working with
configuration. EventPrinter Locale A key type . Represents formats from the Unicode Consortium ’s
Common Locale Data Repository (CLDR) . Implements Format .LogLevel Month The month of the year. Ordering An Ordering is the result of a comparison between two values. RoundingStrategy RoundingStrategy represents the different rounding strategies that can be used by
round_dp_with_strategy.Trim The whitespace preservation behaviour when reading CSV data. Unexpected Unexpected represents an unexpected invocation of any one of the Visitor
trait methods.AbsDiffEq Equality that is defined using the absolute difference of two numbers. Add The addition operator +. AddAssign The addition assignment operator +=. AsTargets Return a reference to single or multiple target variables. BinaryClassification Classification for binary-labels BufferedSubscriber Callsite Trait implemented by callsites. Data Array representation trait. Datelike The common set of methods for date component. DeError The Error trait allows Deserialize implementations to create descriptive
error messages belonging to the Deserializer against which they are
currently running. Debug ? formatting.Deserialize A data structure that can be deserialized from any data format supported
by Serde. Deserializer A data format that can deserialize any data structure supported by
Serde. Display Format trait for an empty format, {}. Div The division operator /. DivAssign The division assignment operator /=. Error Error is a trait representing the basic expectations for error values,
i.e., values of type E in Result<T, E> .Fit Fittable algorithms FitWith Incremental algorithms Float Floating point numbers Flushable FromPrimitive A generic trait for converting a number to a value. FromStr Parse a value from a string Instrument Attaches spans to a std::future::Future . Into A value-to-value conversion that consumes the input value. The
opposite of From . Itertools An Iterator blanket implementation that provides extra adaptors and
methods. MathematicalOps Trait exposing various mathematical operations that can be applied using a Decimal. This is only
present when the maths feature has been enabled, e.g. by adding the crate with Mul The multiplication operator *. MulAssign The multiplication assignment operator *=. MultiTargetRegression Regression metrices trait for multiple targets. Neg The unary negation operator -. Num The base trait for numeric types, covering 0 and 1 values,
comparisons, basic numeric operations, and string conversion. NumOps Generic trait for types implementing basic numeric operations One Defines a multiplicative identity element for Self. ParamGuard A set of hyperparameters whose values have not been checked for validity. A reference to the
checked hyperparameters can only be obtained after checking has completed. If the
Transformer, Fit, or FitWith traits have been implemented on the checked
hyperparameters, they will also be implemented on the unchecked hyperparameters with the
checking step done automatically. Pow Binary operator for raising a value to a power. Predict Predict with model PredictInplace Predict with model into a mutable reference of targets. Read The Read trait allows for reading bytes from a source. Real A trait for real number types that do not necessarily have
floating-point-specific characteristics such as NaN and infinity. Records Record trait Rem The remainder operator %. Serialize A data structure that can be serialized into any data format supported
by Serde. Serializer A data format that can serialize any data structure supported by Serde. Signed Useful functions for signed numbers (i.e. numbers that can be negative). SilhouetteScore Evaluates the quality of a clustering using euclidean distance. SingleTargetRegression Regression metrices trait for single targets. Sub The subtraction operator -. SubAssign The subtraction assignment operator -=. Subscriber Trait representing the functions required to collect trace data. Sum Trait to represent types that can be created by summing up an iterator. ToConfusionMatrix Classification for multi-label evaluation ToFormattedString A key trait . Gives numbers the to_formatted_string method.ToPrimitive A generic trait for converting a value to a number. Transformer Transformation algorithms UlpsEq Equality comparisons between two numbers using both the absolute difference and ULPs
(Units in Last Place) based comparisons. UnicodeSegmentation Methods for segmenting strings according to
Unicode Standard Annex #29 . Value A field value of an erased type. Visitor This trait represents a visitor that walks through a deserializer. Write A trait for objects which are byte-oriented sinks. WriteFormatted A key trait . Gives types in the standard library that implement io::Write
or fmt::Write , such as &mut [u8] and &mut String, a write_formatted method for writing
formatted numbers.Zero Defines an additive identity element for Self. concatenate Concatenate arrays along the given axis. configure_tracing Initializes the logging subscriber. create_file_logging_subscriber init_default_file_logging init_file_logging init_test_logger init_test_logger_with_max_level_filter setup_buffered_tracing setup_default_buffered_tracing setup_dynamic_tracing Array2 two-dimensional array BayesResult Simplified Result using NaiveBayesError as error type Dataset Dataset DatasetView DatasetView Duration Alias of TimeDelta . disable instrument Instruments a function to create and enter a tracing span every time
the function is called. traced_test Builder Create a builder struct for the deriving struct. CloneGetters CopyGetters Debug Derive macro generating an impl of the trait Debug. Deserialize Error Getters MutGetters Serialize Setters WithSetters